* ver: 1.5.6 add html procession method
* ver: 1.5.5 change / to os.sep so it can work on windows platform
* ver: 1.5.4 mid value filter and get acc from pre and tru
* ver: 1.5.3 sing voice sepration
* ver: 1.4.6 split youZhang
* ver: 1.4.4 fdu-network and update countDays
* ver: 1.4.3 downGUI beta
* ver: 1.4.1  calc combine audio features and extract subFeat from the combine one
* ver: 1.4.0  calc librosa spectral feature
* ver: 1.3.31 downGUI
* ver: 1.3.30 youtubePdfDown
* ver: 1.3.28 spec gammatone and both plot
* ver: 1.3.27 add gammatone spec
* ver: 1.3.25 get spec and graph spec
* ver: 1.3.23 reduce List Filter
* ver: 1.3.21 download youtube link
* ver: 1.3.20 write mat
* ver: 1.3.19 scaler
* ver: 1.3.18 normalize data
* ver: 1.3.17 ./ 
* ver: 1.3.16 ./
* ver: 1.3.15 /docs
* ver: 1.3.14 del datafile for subdir
* ver: 1.3.13 modify index
* ver: 1.3.12 index.md modify
* ver: 1.3.11 add datafiles
* ver: 1.3.10 add normalization dataset minmax and meanstd
* ver: 1.3.9  just add chang log modify long description